Introduction
============

The ``plonetheme.burned`` package uses the *theming & packaging* features
available in `plone.app.theming`_ to make the theme `burned`_ easily
available in `Plone 4.1`_.

.. image:: http://svn.plone.org/svn/collective/plonetheme.burned/trunk/screenshot.png

.. _`burned`: http://www.freecsstemplates.org/preview/burned/
.. _`plone.app.theming`: http://pypi.python.org/pypi/plone.app.theming
.. _`Plone 4.1`: http://pypi.python.org/pypi/Plone/4.1rc2
